@@ -7,7 +7,7 @@ use JSON;
 use Plack::Request;
 use URI::Escape;
 
-our $VERSION = '2.0.3';
+our $VERSION = '2.0.8';
 
 our @ISA = ('Plack::Request');
 
@@ -27,9 +27,9 @@ sub new {
       if ( $self->env->{X_ORIGINAL_URI} );
     $self->env->{PATH_INFO} =~ s|//+|/|g;
 
-    if ( my $tmp = $self->script_name ) {
-        $self->env->{PATH_INFO} =~ s|^$tmp|/|;
-    }
+    #if ( my $tmp = $self->script_name ) {
+    #    $self->env->{PATH_INFO} =~ s|^$tmp|/|;
+    #}
     $self->env->{PATH_INFO} ||= '/';
     $self->env->{REQUEST_URI} =~ s|^//+|/|g;
     $self->{uri}         = uri_unescape( $self->env->{REQUEST_URI} );
@@ -46,7 +46,11 @@ sub uri { $_[0]->{uri} }
 sub userData {
     my ( $self, $v ) = @_;
     return $self->{userData} = $v if ($v);
-    return $self->{userData} || { _whatToTrace => $self->{user}, };
+    return $self->{userData}
+      || {
+        ( $Lemonldap::NG::Handler::Main::tsv->{whatToTrace}
+              || '_whatToTrace' ) => $self->{user},
+      };
 }
 
 sub respHeaders {
@@ -55,11 +59,17 @@ sub respHeaders {
     return $self->{respHeaders};
 }
 
+sub spliceHdrs {
+    my ($self) = @_;
+    return splice @{ $self->{respHeaders} };
+}
+
 sub accept        { $_[0]->env->{HTTP_ACCEPT} }
 sub encodings     { $_[0]->env->{HTTP_ACCEPT_ENCODING} }
 sub languages     { $_[0]->env->{HTTP_ACCEPT_LANGUAGE} }
 sub authorization { $_[0]->env->{HTTP_AUTHORIZATION} }
 sub hostname      { $_[0]->env->{HTTP_HOST} }
+sub origin        { $_[0]->env->{HTTP_ORIGIN} }
 sub referer       { $_[0]->env->{REFERER} }
 sub query_string  { $_[0]->env->{QUERY_STRING} }
 
@@ -118,18 +128,18 @@ PSGIs
 =head1 SYNOPSIS
 
   package My::PSGI;
-  
+
   use base Lemonldap::NG::Common::PSGI;
-  
+
   # See Lemonldap::NG::Common::PSGI
   ...
-  
+
   sub handler {
     my ( $self, $req ) = @_;
     # Do something and return a PSGI response
     # NB: $req is a Lemonldap::NG::Common::PSGI::Request object
     if ( $req->accept eq 'text/plain' ) { ... }
-    
+
     return [ 200, [ 'Content-Type' => 'text/plain' ], [ 'Body lines' ] ];
   }
 
@@ -189,6 +199,10 @@ Example:
   # Add header
   $req->respHeaders->{"X-Key"} = "Value";
 
+=head2 spliceHdrs
+
+Returns headers array and flush it.
+
 =head2 set_param( $key, $value )
 
 L<Plack::Request> param() method is read-only. This method can be used to
